/**
  *  \file game/objl-user.cc
  *
  *  (c) 2001-2020 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/objlist.h"
#include "util/conf.h"
#include "game/pref.h"

static ConfigIntOption opt_sort_ship(getUserPreferences(), "Sort.Ship", ValueIntParser::instance);

int
getSortOrderConfig()
{
    return opt_sort_ship();
}

void
setSortOrderConfig(int n)
{
    opt_sort_ship.set(n);
}

void
GObjectList::postprocessUser(bool with_dividers)
{
    switch (opt_sort_ship()) {
     case SortByOwner:
        sort(sortByOwner);
        if (with_dividers)
            addDividers(diviOwner);
        break;
     case SortByHull:
        sort(sortByHull);
        if (with_dividers)
            addDividers(diviHull);
        break;
     case SortByMass:
        sort(sortByMass);
        break;
     case SortByFleet:
        sort(sortByFleet);
        if (with_dividers)
            addDividers(diviFleet);
        break;
     case SortByTowGroup:
        sort(sortByTowGroup);
        if (with_dividers)
            addDividers(diviTowGroup);
        break;
     case SortByBattleOrder:
        sort(sortByBattleOrder);
        if (with_dividers) {
            addDividers(diviBattleOrder);
        }
        break;
     case SortByLocation:
        sort(sortByLocation);
        if (with_dividers) {
            addDividers(diviLocation);
        }
        break;
     case SortByHullMass:
        sort(sortByHullMass);
        break;
     case SortByDamage:
        sort(sortByDamage);
        break;
     case SortByName:
        sort(sortByName);
        break;
     case SortByNewPosition:
        sort(sortByNewLocation);
        if (with_dividers) {
            addDividers(diviNewLocation);
        }
        break;
     default:
        // Fall back to sorting by Id
        sort(sortById);
        break;
    }
}
